#!/bin/env python3

import sys
import subprocess

def main():
    args = sys.argv[1:]
    bin = f"kosciuszko-{args.pop(0)}"

    l = [bin]
    l.extend(args)

    try:
            subprocess.run(l)
    except FileNotFoundError:
            print("Command not found")




#!/usr/bin/python3
# pylint: disable=missing-docstring

import os
import sys
import argparse
from pathlib import Path
import pkg_resources
from libkosciuszko import Kosciuszko

def main():
    version = pkg_resources.require("kosciuszko-utils")[0].version
    parser = argparse.ArgumentParser(description="extract a single file from a kosciuszko store")
    parser.add_argument("--version", action="version", version="%(prog)s {}".format(version))
    parser.add_argument("--gpg-id", nargs=1, help="GPG ID for the store")
    parser.add_argument("--store", nargs=1, help="Filename of the store (vault)")
    parser.add_argument("--output", nargs='?', help="directory to write to (otherwise squashfs-root)")

    args = parser.parse_args(sys.argv[1:])
    gpg_id = vars(args)["gpg_id"]
    store = vars(args)["store"]
    output = vars(args)["output"]

    kosciuszko = Kosciuszko(gpg_id[0], store[0])
    ls = kosciuszko.list()

    if not output is not None:
        output = "squashfs-root"

    for filename in ls:
        if filename == "squashfs-root":
            os.makedirs(output, exist_ok=True)
            continue
        filename = Path(filename).name
        data = kosciuszko.getfile(filename)
        with open(f"{output}/{filename}", 'ab') as fh:
            fh.write(data)



#!/usr/bin/python3
# pylint: disable=missing-docstring

import sys
import argparse
from pathlib import Path
import pkg_resources
import uuid
from libkosciuszko import Kosciuszko

def main():
    version = pkg_resources.require("kosciuszko-utils")[0].version
    parser = argparse.ArgumentParser(description="add a file to a kosciuszko store")
    parser.add_argument("--version", action="version", version="%(prog)s {}".format(version))
    parser.add_argument("--gpg-id", nargs=1, help="GPG ID for the store")
    parser.add_argument("--store", nargs=1, help="Filename of the store (vault)")
    parser.add_argument("--filename", nargs='?', help="name of file to add")
    parser.add_argument("file", nargs='?', help="file to add (optional; otherwise read from stdin)")

    args = parser.parse_args(sys.argv[1:])
    gpg_id = vars(args)["gpg_id"]
    store = vars(args)["store"]
    fileinput = vars(args)["file"]
    filename = vars(args)["filename"]

    kosciuszko = Kosciuszko(gpg_id[0], store[0])

    if filename is not None and fileinput is not None:
        # Read the file and  store with filename
        with open(fileinput, 'rb') as fh:
            data = fh.read()
        kosciuszko.addfile(filename, data)
    if not filename is not None and fileinput is not None:
        # Read the file and store without changing the filename
        with open(fileinput, 'rb') as fh:
            data = fh.read()
        filename = Path(fileinput)
        filename = filename.name
        kosciuszko.addfile(filename, data)
    if filename is not None and not fileinput is not None:
        # Read from stdin and store with filename
        with open('/dev/stdin') as fh:
            data = fh.read()
        if isinstance(data, str):
            data = data.encode('utf-8')
        kosciuszko.addfile(filename, data)
    if not filename is not None and not fileinput is not None:
        # Read from stdin and store with random filename
        filename = (uuid.uuid4())
        with open('/dev/stdin', 'rb') as fh:
            data = fh.read()
        if isinstance(data, str):
            data = data.encode('utf-8')
        kosciuszko.addfile(filename, data)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name = "kosciuszko-utils",
    version="0.2.0",
    packages=['kosciuszko', 'kosciuszko_new', 'kosciuszko_extract', 'kosciuszko_extract_file', 'kosciuszko_list', 'kosciuszko_addfile'],
    package_dir={
        'kosciuszko': 'src/kosciuszko',
        'kosciuszko_new': 'src/new',
        'kosciuszko_extract': 'src/extract',
        'kosciuszko_extract_file': 'src/extract_file',
        'kosciuszko_list': 'src/list',
        'kosciuszko_addfile': 'src/addfile',
    },
    url="https://git.sr.ht/~happy_shredder/kosciuszko-utils",
    author="happy_shredder",
    author_email="contact@etage.io",
    description="Library for managing kosciuszko vaults",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: POSIX :: Linux",
        "Topic :: Security :: Cryptography",
        "Intended Audience :: End Users/Desktop",
        "Environment :: Console",
        "Development Status :: 3 - Alpha"
    ],
    install_requires=['libkosciuszko'],
    python_requires='>=3.7',
    entry_points={
        'console_scripts': ['kosciuszko=kosciuszko.__init__:main', 'kosciuszko-new=kosciuszko_new.__init__:main', 'kosciuszko-extract=kosciuszko_extract.__init__:main', 'kosciuszko-extract-file=kosciuszko_extract_file.__init__:main', 'kosciuszko-list=kosciuszko_list.__init__:main', 'kosciuszko-addfile=kosciuszko_addfile.__init__:main'],
        }
)
